@@ -2,12 +2,14 @@ package Net::Pcap::FindDevice;
 use strict;
 use Net::Pcap; # just for the convenience function below
 use Carp qw(croak);
-use Exporter::Lite;
+use Exporter 'import';
 
 use vars qw($VERSION @EXPORT);
-$VERSION = '0.22';
+$VERSION = '0.23';
 @EXPORT = qw(find_device);
 
+# TODO: Add diagnosis function to tell the user what the "best" function is
+
 =head1 NAME
 
 Net::Pcap::FindDevice - find the "best" network device for sniffing
@@ -80,7 +82,9 @@ NO_DEVICE
       croak "Don't know how to handle $device_name as a Net::Pcap device";
     };
   } else {
-    use Data::Dumper;
+    # TODO: Remove Data::Dumper dependency
+    #use Data::Dumper;
+    #warn Dumper \%devinfo;
     # 'any' is disabled as it returns information in a format
     # I don't understand
     #if (exists $devinfo{any}) {
@@ -93,14 +97,16 @@ NO_DEVICE
       # one with the default gateway:
 
       # First, get the default gateway by using
-      # `netstat -rn`
+      # `netstat -rn` and looking for the interface tied to the gateway
       my $device_ip;
       my $re_if = $^O eq 'MSWin32'
-                  ? qr/^\s*(?:0.0.0.0)\s+(\S+)\s+(\S+)\s+/
+                  #         route        mask    gateway interface
+                  ? qr/^\s*(?:0.0.0.0)\s+(?:\S+)\s+(\S+)\s+(\S+)/
                   : qr/^(?:0.0.0.0|default)\s+(\S+)\s+.*?(\S+)\s*$/;
       for (qx{netstat -rn}) {
         if ( /$re_if/ ) {
           $device_ip = $2;
+          #warn "Found $2 in $_";
           last;
         };
       };
